@@ -39,14 +39,15 @@ const Sidebar = imports.sidebar;
 const Utils = imports.utils;
 const Path = imports.path;
 const MapLocation = imports.mapLocation;
-const MapSource = imports.mapSource;
 const UserLocation = imports.userLocation;
 const Geoclue = imports.geoclue;
 const _ = imports.gettext.gettext;
 
 const MapType = {
-    STREET: 'MapsStreetSource',
-    AERIAL: 'MapsAerialSource'
+    STREET:  Champlain.MAP_SOURCE_OSM_MAPQUEST,
+    AERIAL:  Champlain.MAP_SOURCE_OSM_AERIAL_MAP,
+    CYCLING: Champlain.MAP_SOURCE_OSM_CYCLE_MAP,
+    TRANSIT: Champlain.MAP_SOURCE_OSM_TRANSPORT_MAP
 };
 
 const MapView = new Lang.Class({
@@ -77,6 +78,7 @@ const MapView = new Lang.Class({
         this._userLocationLayer.set_selection_mode(Champlain.SelectionMode.SINGLE);
         this.view.add_layer(this._userLocationLayer);
 
+        this._factory = Champlain.MapSourceFactory.dup_default();
         this.setMapType(MapType.STREET);
 
         this._zoomControl = new ZoomControl.ZoomControl(this);
@@ -89,22 +91,14 @@ const MapView = new Lang.Class({
     },
 
     setMapType: function(mapType) {
-        if (mapType === MapType.AERIAL)
-            this.view.map_source = MapSource.createAerialSource();
-        else
-            this.view.map_source = MapSource.createStreetSource();
-
-        if (!this._attribution) {
-            this._attribution = new MapSource.AttributionLogo(this.view);
-            this.view.add_child(this._attribution);
-        }
+        let source = this._factory.create_cached_source(mapType);
+        this.view.set_map_source(source);
     },
 
     geocodeSearch: function(searchString, searchCompleteCallback) {
         let forward = Geocode.Forward.new_for_string(searchString);
         let places = [];
-        let answerCount =
-            Application.settings.get_value('max-search-results').get_int32();
+        let answerCount = Application.settings.get('max-search-results');
 
         forward.set_answer_count(answerCount);
         forward.search_async (null, (function(forward, res) {
